# 🐍 ChipScoPy README


[![](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)


![](https://raw.githubusercontent.com/Xilinx/chipscopy/master/docs/images/chipscopy_logo_head_right_transparent_background.png)

ChipScoPy is an open-source project from Xilinx® that enables high-level control of Versal debug IP running in hardware.
Using a simple Python API, developers can control and communicate with ChipScope® debug IP such as the Integrated Logic
Analyzer (ILA), Virtual IO (VIO), device memory access, and more.

-------------------------------------------------------------------------------

![](https://raw.githubusercontent.com/Xilinx/chipscopy/master/docs/images/chipscopy_overview.png)

-------------------------------------------------------------------------------

[ChipScoPy Overview](https://xilinx.github.io/chipscopy/2021.1/overview.html)

-------------------------------------------------------------------------------

[System Requirements](https://xilinx.github.io/chipscopy/2021.1/system_requirements.html)

-------------------------------------------------------------------------------

[ChipScoPy Installation](https://xilinx.github.io/chipscopy/2021.1/chipscopy_installation.html)

-------------------------------------------------------------------------------

[ChipScoPy Examples](https://github.com/Xilinx/chipscopy/tree/master/chipscopy/examples)

-------------------------------------------------------------------------------

[API Documentation](https://xilinx.github.io/chipscopy/)

-------------------------------------------------------------------------------
